@@ -1,5 +1,5 @@
 package Statocles;
-our $VERSION = '0.081';
+our $VERSION = '0.082';
 # ABSTRACT: A static site generator
 
 # The currently-running site.
@@ -31,7 +31,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.081
+version 0.082
 
 =head1 SYNOPSIS
 
@@ -142,16 +142,12 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Doug Bell Ferenc Erki Joel Berger Kent Fredric Konrad Bucheli tadegenban Vladimir Lettiev William Lindley
+=for stopwords Ferenc Erki Joel Berger Kent Fredric Konrad Bucheli tadegenban Vladimir Lettiev William Lindley
 
 =over 4
 
 =item *
 
-Doug Bell <doug@preaction.me>
-
-=item *
-
 Ferenc Erki <erkiferenc@gmail.com>
 
 =item *
