@@ -1,5 +1,5 @@
 package Statocles::Plugin::HTMLLint;
-our $VERSION = '0.081';
+our $VERSION = '0.082';
 # ABSTRACT: Check HTML for common errors and issues
 
 use Statocles::Base 'Class';
@@ -35,22 +35,23 @@ sub check_pages {
     my ( $self, $event ) = @_;
     my @plugins = @{ $self->plugins };
 
+    my $lint = HTML::Lint::Pluggable->new;
+    $lint->load_plugins( @plugins );
+
     for my $page ( @{ $event->pages } ) {
         if ( $page->DOES( 'Statocles::Page::Document' ) ) {
             my $html = $page->render( site => $event->emitter );
             my $page_url = $page->path;
 
-            my $lint = HTML::Lint::Pluggable->new;
-            $lint->load_plugins( @plugins );
+            $lint->newfile( $page_url );
             $lint->parse( $html );
+            $lint->eof;
+        }
+    }
 
-            if ( $lint->errors ) {
-                $event->emitter->log->warn( "Lint failures on $page_url:" );
-                for my $error ( $lint->errors ) {
-                    $event->emitter->log->warn( "-" . $error->as_string );
-                }
-            }
-
+    if ( my @errors = $lint->errors ) {
+        for my $error ( @errors ) {
+            $event->emitter->log->warn( "-" . $error->as_string );
         }
     }
 }
@@ -80,7 +81,7 @@ Statocles::Plugin::HTMLLint - Check HTML for common errors and issues
 
 =head1 VERSION
 
-version 0.081
+version 0.082
 
 =head1 SYNOPSIS
 
