@@ -1,5 +1,5 @@
 package Statocles::Plugin::Highlight;
-our $VERSION = '0.081';
+our $VERSION = '0.082';
 # ABSTRACT: Highlight code and configuration syntax
 
 #pod =head1 SYNOPSIS
@@ -94,6 +94,12 @@ has style => (
 #pod     <p>This example Perl code prints the string "Hello, World" to the screen:</p>
 #pod     %= highlight Perl => 'print "Hello, World\n"'
 #pod
+#pod We can override the style we want by passing in a C<-style> option:
+#pod
+#pod     %= highlight -style => 'solarized-dark', Perl => begin
+#pod     print "Hello, World!\n";
+#pod     % end
+#pod
 #pod =cut
 
 my $hl = Syntax::Highlight::Engine::Kate->new(
@@ -127,7 +133,15 @@ my $hl = Syntax::Highlight::Engine::Kate->new(
 );
 
 sub highlight {
-    my ( $self, $args, $type, $text ) = @_;
+    my ( $self, $args, @args ) = @_;
+
+    # Last two args are always type and text and are required
+    my ( $text, $type ) = ( pop @args, pop @args );
+
+    # Other args are options
+    my %opt = @args;
+
+    my $style = $opt{ -style } || $self->style;
 
     # Handle Mojolicious begin/end
     if ( ref $text eq 'CODE' ) {
@@ -142,7 +156,7 @@ sub highlight {
     my $page = $args->{page} || $args->{self};
     if ( $page ) {
         # Add the appropriate stylesheet to the page
-        my $style_url = $page->site->theme->url( '/plugin/highlight/' . $self->style . '.css' );
+        my $style_url = $page->site->theme->url( '/plugin/highlight/' . $style . '.css' );
         if ( !grep { $_->href eq $style_url } $page->links( 'stylesheet' ) ) {
             $page->links( stylesheet => $style_url );
         }
@@ -196,7 +210,7 @@ Statocles::Plugin::Highlight - Highlight code and configuration syntax
 
 =head1 VERSION
 
-version 0.081
+version 0.082
 
 =head1 SYNOPSIS
 
@@ -277,6 +291,12 @@ The highlight function adds both C<pre> and C<code> tags.
     <p>This example Perl code prints the string "Hello, World" to the screen:</p>
     %= highlight Perl => 'print "Hello, World\n"'
 
+We can override the style we want by passing in a C<-style> option:
+
+    %= highlight -style => 'solarized-dark', Perl => begin
+    print "Hello, World!\n";
+    % end
+
 =head2 register
 
 Register this plugin with the site. Called automatically.
